module.exports = defineTest({
	description: 'Correctly handles assignment operators on exports',
	options: { output: { name: 'bundle' } }
});
